@@ -4,21 +4,8 @@ use std::path;
 
 use serde::{Deserialize, Serialize};
 
-use crate::module::{FlatpakBuildOptions, FlatpakModule, FlatpakModuleDescription};
-
-#[derive(Clone)]
-#[derive(Deserialize)]
-#[derive(Serialize)]
-#[derive(Debug)]
-pub enum FlatpakManifestFormat {
-    JSON,
-    YAML,
-}
-impl Default for FlatpakManifestFormat {
-    fn default() -> Self {
-        FlatpakManifestFormat::YAML
-    }
-}
+use crate::format::FlatpakManifestFormat;
+use crate::module::{FlatpakBuildOptions, FlatpakModule, FlatpakModuleItem};
 
 /// Main structure for a Flatpak application manifest.
 /// See `man flatpak-manifest` for the flatpak manifest specs.
@@ -217,7 +204,7 @@ pub struct FlatpakApplication {
     /// String members in the array are interpreted as the name of a separate
     /// json or yaml file that contains a module. See below for details.
     #[serde(skip_serializing_if = "Vec::is_empty")]
-    pub modules: Vec<FlatpakModule>,
+    pub modules: Vec<FlatpakModuleItem>,
 }
 impl FlatpakApplication {
     pub fn get_id(&self) -> String {
@@ -332,9 +319,9 @@ impl FlatpakApplication {
     pub fn get_all_module_urls(&self) -> Vec<String> {
         let mut all_urls = vec![];
         for module in &self.modules {
-            let module: &FlatpakModuleDescription = match module {
-                FlatpakModule::Path(_) => continue,
-                FlatpakModule::Description(m) => &m,
+            let module: &FlatpakModule = match module {
+                FlatpakModuleItem::Path(_) => continue,
+                FlatpakModuleItem::Description(m) => &m,
             };
             all_urls.append(&mut module.get_all_urls());
         }
@@ -346,9 +333,9 @@ impl FlatpakApplication {
             Some(m) => m,
             None => return None,
         };
-        let main_module: &FlatpakModuleDescription = match main_module {
-            FlatpakModule::Path(_) => return None,
-            FlatpakModule::Description(m) => m,
+        let main_module: &FlatpakModule = match main_module {
+            FlatpakModuleItem::Path(_) => return None,
+            FlatpakModuleItem::Description(m) => m,
         };
         return main_module.get_main_url();
     }
@@ -356,7 +343,7 @@ impl FlatpakApplication {
     pub fn get_max_depth(&self) -> i32 {
         let mut max_depth: i32 = 1;
         for module in &self.modules {
-            if let FlatpakModule::Description(module_description) = module {
+            if let FlatpakModuleItem::Description(module_description) = module {
                 let module_depth = module_description.get_max_depth();
                 if module_depth > max_depth {
                     max_depth = module_depth;
@@ -373,14 +360,14 @@ impl FlatpakApplication {
         false
     }
 
-    pub fn get_all_modules_recursively(&self) -> Vec<&FlatpakModule> {
-        let mut all_modules: Vec<&FlatpakModule> = vec![];
+    pub fn get_all_modules_recursively(&self) -> Vec<&FlatpakModuleItem> {
+        let mut all_modules: Vec<&FlatpakModuleItem> = vec![];
         for module in &self.modules {
             all_modules.push(module);
 
             let module = match module {
-                FlatpakModule::Description(d) => d,
-                FlatpakModule::Path(_) => continue,
+                FlatpakModuleItem::Description(d) => d,
+                FlatpakModuleItem::Path(_) => continue,
             };
             for child_module in module.get_all_modules_recursively() {
                 all_modules.push(child_module);
@@ -527,7 +514,7 @@ mod tests {
                     branch: master
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "net.louib.flatpak-review");
             }
@@ -560,7 +547,7 @@ mod tests {
                 "shared-modules/linux-audio/lv2.json"
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "net.louib.flatpak-review");
             }
@@ -600,7 +587,7 @@ mod tests {
                     enable-if: "active-gl-driver"
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "net.pcsx2.PCSX2");
                 assert_eq!(manifest.add_extensions.len(), 3);
@@ -630,7 +617,7 @@ mod tests {
                     "shared-modules/linux-audio/lv2.json"
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "net.louib.flatpak-review");
             }
@@ -661,7 +648,7 @@ mod tests {
 
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "net.louib.flatpak-review");
             }
@@ -698,7 +685,7 @@ mod tests {
                     "shared-modules/linux-audio/lv2.json"
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "net.louib.flatpak-review");
             }
@@ -733,7 +720,7 @@ mod tests {
                         sed -i -e 's/\${\${NAME}_BIN}-NOTFOUND/\${NAME}_BIN-NOTFOUND/' cpp/CMakeLists.txt
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "net.louib.flatpak-review");
             }
@@ -802,7 +789,7 @@ mod tests {
             }
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "org.gnome.SoundJuicer");
             }
@@ -889,7 +876,7 @@ mod tests {
             }
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "org.gnome.SoundJuicer");
             }
@@ -946,7 +933,7 @@ mod tests {
             }
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "org.gnome.Lollypop");
             }
@@ -976,7 +963,7 @@ mod tests {
             }
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.id, "org.freedesktop.Platform.Icontheme.Paper");
                 assert_eq!(manifest.get_id(), "org.freedesktop.Platform.Icontheme.Paper");
@@ -1160,7 +1147,7 @@ mod tests {
                         sha256: 'd80023ab221b3cb89229b632e247035a22c5afaee9a7b3c653bbd702f71c1083'
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(manifest) => {
                 assert_eq!(manifest.app_id, "com.georgefb.haruna");
                 assert_eq!(manifest.get_max_depth(), 3);
